agent

package
v0.0.0-...-60df2ce Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package agent provides agent-related API handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Agent

type Agent struct {
	// JobClient provides job-based operations for agent queries.
	JobClient client.JobClient
	// contains filtered or unexported fields
}

Agent implementation of the Agent APIs operations.

func New

func New(
	logger *slog.Logger,
	jobClient client.JobClient,
) *Agent

New factory to create a new instance.

func (*Agent) GetAgent

GetAgent discovers all active agents in the fleet.

func (*Agent) GetAgentDetails

GetAgentDetails retrieves detailed information about a specific agent.

Directories

Path Synopsis
Package gen provides primitives to interact with the openapi HTTP API.
Package gen provides primitives to interact with the openapi HTTP API.

Jump to