Documentation
¶
Overview ¶
Package gen contains generated code for the node API.
Package gen provides primitives to interact with the openapi HTTP API.
Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.1 DO NOT EDIT.
Index ¶
- Constants
- func RegisterHandlers(router EchoRouter, si ServerInterface)
- func RegisterHandlersWithBaseURL(router EchoRouter, si ServerInterface, baseURL string)
- type CommandExecRequest
- type CommandResultCollectionResponse
- type CommandResultItem
- type CommandShellRequest
- type DNSConfigCollectionResponse
- type DNSConfigResponse
- type DNSConfigUpdateRequest
- type DNSUpdateCollectionResponse
- type DNSUpdateResultItem
- type DNSUpdateResultItemStatus
- type DiskCollectionResponse
- type DiskResponse
- type DiskResultItem
- type DisksResponse
- type EchoRouter
- type ErrorResponse
- type GetNodeDisk200JSONResponse
- type GetNodeDisk400JSONResponse
- type GetNodeDisk401JSONResponse
- type GetNodeDisk403JSONResponse
- type GetNodeDisk500JSONResponse
- type GetNodeDiskRequestObject
- type GetNodeDiskResponseObject
- type GetNodeHostname200JSONResponse
- type GetNodeHostname400JSONResponse
- type GetNodeHostname401JSONResponse
- type GetNodeHostname403JSONResponse
- type GetNodeHostname500JSONResponse
- type GetNodeHostnameRequestObject
- type GetNodeHostnameResponseObject
- type GetNodeLoad200JSONResponse
- type GetNodeLoad400JSONResponse
- type GetNodeLoad401JSONResponse
- type GetNodeLoad403JSONResponse
- type GetNodeLoad500JSONResponse
- type GetNodeLoadRequestObject
- type GetNodeLoadResponseObject
- type GetNodeMemory200JSONResponse
- type GetNodeMemory400JSONResponse
- type GetNodeMemory401JSONResponse
- type GetNodeMemory403JSONResponse
- type GetNodeMemory500JSONResponse
- type GetNodeMemoryRequestObject
- type GetNodeMemoryResponseObject
- type GetNodeNetworkDNSByInterface200JSONResponse
- type GetNodeNetworkDNSByInterface400JSONResponse
- type GetNodeNetworkDNSByInterface401JSONResponse
- type GetNodeNetworkDNSByInterface403JSONResponse
- type GetNodeNetworkDNSByInterface500JSONResponse
- type GetNodeNetworkDNSByInterfaceRequestObject
- type GetNodeNetworkDNSByInterfaceResponseObject
- type GetNodeOS200JSONResponse
- type GetNodeOS400JSONResponse
- type GetNodeOS401JSONResponse
- type GetNodeOS403JSONResponse
- type GetNodeOS500JSONResponse
- type GetNodeOSRequestObject
- type GetNodeOSResponseObject
- type GetNodeStatus200JSONResponse
- type GetNodeStatus400JSONResponse
- type GetNodeStatus401JSONResponse
- type GetNodeStatus403JSONResponse
- type GetNodeStatus500JSONResponse
- type GetNodeStatusRequestObject
- type GetNodeStatusResponseObject
- type GetNodeUptime200JSONResponse
- type GetNodeUptime400JSONResponse
- type GetNodeUptime401JSONResponse
- type GetNodeUptime403JSONResponse
- type GetNodeUptime500JSONResponse
- type GetNodeUptimeRequestObject
- type GetNodeUptimeResponseObject
- type Hostname
- type HostnameCollectionResponse
- type HostnameResponse
- type LoadAverageResponse
- type LoadCollectionResponse
- type LoadResultItem
- type MemoryCollectionResponse
- type MemoryResponse
- type MemoryResultItem
- type NodeStatusCollectionResponse
- type NodeStatusResponse
- type OSInfoCollectionResponse
- type OSInfoResponse
- type OSInfoResultItem
- type PingCollectionResponse
- type PingResponse
- type PostNodeCommandExec202JSONResponse
- type PostNodeCommandExec400JSONResponse
- type PostNodeCommandExec401JSONResponse
- type PostNodeCommandExec403JSONResponse
- type PostNodeCommandExec500JSONResponse
- type PostNodeCommandExecJSONRequestBody
- type PostNodeCommandExecRequestObject
- type PostNodeCommandExecResponseObject
- type PostNodeCommandShell202JSONResponse
- type PostNodeCommandShell400JSONResponse
- type PostNodeCommandShell401JSONResponse
- type PostNodeCommandShell403JSONResponse
- type PostNodeCommandShell500JSONResponse
- type PostNodeCommandShellJSONRequestBody
- type PostNodeCommandShellRequestObject
- type PostNodeCommandShellResponseObject
- type PostNodeNetworkPing200JSONResponse
- type PostNodeNetworkPing400JSONResponse
- type PostNodeNetworkPing401JSONResponse
- type PostNodeNetworkPing403JSONResponse
- type PostNodeNetworkPing500JSONResponse
- type PostNodeNetworkPingJSONBody
- type PostNodeNetworkPingJSONRequestBody
- type PostNodeNetworkPingRequestObject
- type PostNodeNetworkPingResponseObject
- type PutNodeNetworkDNS202JSONResponse
- type PutNodeNetworkDNS400JSONResponse
- type PutNodeNetworkDNS401JSONResponse
- type PutNodeNetworkDNS403JSONResponse
- type PutNodeNetworkDNS500JSONResponse
- type PutNodeNetworkDNSJSONRequestBody
- type PutNodeNetworkDNSRequestObject
- type PutNodeNetworkDNSResponseObject
- type ServerInterface
- type ServerInterfaceWrapper
- func (w *ServerInterfaceWrapper) GetNodeDisk(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeHostname(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeLoad(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeMemory(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeNetworkDNSByInterface(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeOS(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeStatus(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) GetNodeUptime(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) PostNodeCommandExec(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) PostNodeCommandShell(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) PostNodeNetworkPing(ctx echo.Context) error
- func (w *ServerInterfaceWrapper) PutNodeNetworkDNS(ctx echo.Context) error
- type StrictHandlerFunc
- type StrictMiddlewareFunc
- type StrictServerInterface
- type UptimeCollectionResponse
- type UptimeResponse
Constants ¶
const (
BearerAuthScopes = "BearerAuth.Scopes"
)
Variables ¶
This section is empty.
Functions ¶
func RegisterHandlers ¶
func RegisterHandlers(router EchoRouter, si ServerInterface)
RegisterHandlers adds each server route to the EchoRouter.
func RegisterHandlersWithBaseURL ¶
func RegisterHandlersWithBaseURL(router EchoRouter, si ServerInterface, baseURL string)
Registers handlers, and prepends BaseURL to the paths, so that the paths can be served under a prefix.
Types ¶
type CommandExecRequest ¶
type CommandExecRequest struct {
// Args Command arguments.
Args *[]string `json:"args,omitempty"`
// Command The executable name or path.
Command string `json:"command" validate:"required,min=1"`
// Cwd Working directory for the command.
Cwd *string `json:"cwd,omitempty"`
// Timeout Timeout in seconds (default 30, max 300).
Timeout *int `json:"timeout,omitempty" validate:"omitempty,min=1,max=300"`
}
CommandExecRequest defines model for CommandExecRequest.
type CommandResultCollectionResponse ¶
type CommandResultCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []CommandResultItem `json:"results"`
}
CommandResultCollectionResponse defines model for CommandResultCollectionResponse.
type CommandResultItem ¶
type CommandResultItem struct {
// Changed Whether the command modified system state.
Changed *bool `json:"changed,omitempty"`
// DurationMs Execution time in milliseconds.
DurationMs *int64 `json:"duration_ms,omitempty"`
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// ExitCode Exit code of the command.
ExitCode *int `json:"exit_code,omitempty"`
// Hostname The hostname of the agent that executed the command.
Hostname string `json:"hostname"`
// Stderr Standard error output of the command.
Stderr *string `json:"stderr,omitempty"`
// Stdout Standard output of the command.
Stdout *string `json:"stdout,omitempty"`
}
CommandResultItem defines model for CommandResultItem.
type CommandShellRequest ¶
type CommandShellRequest struct {
// Command The full shell command string.
Command string `json:"command" validate:"required,min=1"`
// Cwd Working directory for the command.
Cwd *string `json:"cwd,omitempty"`
// Timeout Timeout in seconds (default 30, max 300).
Timeout *int `json:"timeout,omitempty" validate:"omitempty,min=1,max=300"`
}
CommandShellRequest defines model for CommandShellRequest.
type DNSConfigCollectionResponse ¶
type DNSConfigCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []DNSConfigResponse `json:"results"`
}
DNSConfigCollectionResponse defines model for DNSConfigCollectionResponse.
type DNSConfigResponse ¶
type DNSConfigResponse struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent that served this config.
Hostname string `json:"hostname"`
// SearchDomains List of search domains.
SearchDomains *[]string `json:"search_domains,omitempty"`
// Servers List of configured DNS servers.
Servers *[]string `json:"servers,omitempty"`
}
DNSConfigResponse defines model for DNSConfigResponse.
type DNSConfigUpdateRequest ¶
type DNSConfigUpdateRequest struct {
// InterfaceName The name of the network interface to apply DNS configuration to. Must only contain letters and numbers.
InterfaceName string `json:"interface_name" validate:"required,alphanum"`
// SearchDomains New list of search domains to configure.
SearchDomains *[]string `json:"search_domains,omitempty" validate:"required_without=Servers,omitempty,dive,hostname,min=1"`
// Servers New list of DNS servers to configure.
Servers *[]string `json:"servers,omitempty" validate:"required_without=SearchDomains,omitempty,dive,ip,min=1"`
}
DNSConfigUpdateRequest defines model for DNSConfigUpdateRequest.
type DNSUpdateCollectionResponse ¶
type DNSUpdateCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []DNSUpdateResultItem `json:"results"`
}
DNSUpdateCollectionResponse defines model for DNSUpdateCollectionResponse.
type DNSUpdateResultItem ¶
type DNSUpdateResultItem struct {
// Changed Whether the DNS configuration was actually modified.
Changed *bool `json:"changed,omitempty"`
Error *string `json:"error,omitempty"`
Hostname string `json:"hostname"`
Status DNSUpdateResultItemStatus `json:"status"`
}
DNSUpdateResultItem defines model for DNSUpdateResultItem.
type DNSUpdateResultItemStatus ¶
type DNSUpdateResultItemStatus string
DNSUpdateResultItemStatus defines model for DNSUpdateResultItem.Status.
const ( Failed DNSUpdateResultItemStatus = "failed" Ok DNSUpdateResultItemStatus = "ok" )
Defines values for DNSUpdateResultItemStatus.
type DiskCollectionResponse ¶
type DiskCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []DiskResultItem `json:"results"`
}
DiskCollectionResponse defines model for DiskCollectionResponse.
type DiskResponse ¶
type DiskResponse struct {
// Free Free disk space in bytes.
Free int `json:"free"`
// Name Disk identifier, e.g., "/dev/sda1".
Name string `json:"name"`
// Total Total disk space in bytes.
Total int `json:"total"`
// Used Used disk space in bytes.
Used int `json:"used"`
}
DiskResponse Local disk usage information.
type DiskResultItem ¶
type DiskResultItem struct {
// Disks List of local disk usage information.
Disks *DisksResponse `json:"disks,omitempty"`
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent.
Hostname string `json:"hostname"`
}
DiskResultItem defines model for DiskResultItem.
type DisksResponse ¶
type DisksResponse = []DiskResponse
DisksResponse List of local disk usage information.
type EchoRouter ¶
type EchoRouter interface {
CONNECT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
DELETE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
GET(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
HEAD(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
OPTIONS(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
PATCH(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
POST(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
PUT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
TRACE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
}
This is a simple interface which specifies echo.Route addition functions which are present on both echo.Echo and echo.Group, since we want to allow using either of them for path registration
type ErrorResponse ¶
type ErrorResponse = externalRef0.ErrorResponse
ErrorResponse defines model for ErrorResponse.
type GetNodeDisk200JSONResponse ¶
type GetNodeDisk200JSONResponse DiskCollectionResponse
func (GetNodeDisk200JSONResponse) VisitGetNodeDiskResponse ¶
func (response GetNodeDisk200JSONResponse) VisitGetNodeDiskResponse(w http.ResponseWriter) error
type GetNodeDisk400JSONResponse ¶
type GetNodeDisk400JSONResponse externalRef0.ErrorResponse
func (GetNodeDisk400JSONResponse) VisitGetNodeDiskResponse ¶
func (response GetNodeDisk400JSONResponse) VisitGetNodeDiskResponse(w http.ResponseWriter) error
type GetNodeDisk401JSONResponse ¶
type GetNodeDisk401JSONResponse externalRef0.ErrorResponse
func (GetNodeDisk401JSONResponse) VisitGetNodeDiskResponse ¶
func (response GetNodeDisk401JSONResponse) VisitGetNodeDiskResponse(w http.ResponseWriter) error
type GetNodeDisk403JSONResponse ¶
type GetNodeDisk403JSONResponse externalRef0.ErrorResponse
func (GetNodeDisk403JSONResponse) VisitGetNodeDiskResponse ¶
func (response GetNodeDisk403JSONResponse) VisitGetNodeDiskResponse(w http.ResponseWriter) error
type GetNodeDisk500JSONResponse ¶
type GetNodeDisk500JSONResponse externalRef0.ErrorResponse
func (GetNodeDisk500JSONResponse) VisitGetNodeDiskResponse ¶
func (response GetNodeDisk500JSONResponse) VisitGetNodeDiskResponse(w http.ResponseWriter) error
type GetNodeDiskRequestObject ¶
type GetNodeDiskRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeDiskResponseObject ¶
type GetNodeDiskResponseObject interface {
VisitGetNodeDiskResponse(w http.ResponseWriter) error
}
type GetNodeHostname200JSONResponse ¶
type GetNodeHostname200JSONResponse HostnameCollectionResponse
func (GetNodeHostname200JSONResponse) VisitGetNodeHostnameResponse ¶
func (response GetNodeHostname200JSONResponse) VisitGetNodeHostnameResponse(w http.ResponseWriter) error
type GetNodeHostname400JSONResponse ¶
type GetNodeHostname400JSONResponse externalRef0.ErrorResponse
func (GetNodeHostname400JSONResponse) VisitGetNodeHostnameResponse ¶
func (response GetNodeHostname400JSONResponse) VisitGetNodeHostnameResponse(w http.ResponseWriter) error
type GetNodeHostname401JSONResponse ¶
type GetNodeHostname401JSONResponse externalRef0.ErrorResponse
func (GetNodeHostname401JSONResponse) VisitGetNodeHostnameResponse ¶
func (response GetNodeHostname401JSONResponse) VisitGetNodeHostnameResponse(w http.ResponseWriter) error
type GetNodeHostname403JSONResponse ¶
type GetNodeHostname403JSONResponse externalRef0.ErrorResponse
func (GetNodeHostname403JSONResponse) VisitGetNodeHostnameResponse ¶
func (response GetNodeHostname403JSONResponse) VisitGetNodeHostnameResponse(w http.ResponseWriter) error
type GetNodeHostname500JSONResponse ¶
type GetNodeHostname500JSONResponse externalRef0.ErrorResponse
func (GetNodeHostname500JSONResponse) VisitGetNodeHostnameResponse ¶
func (response GetNodeHostname500JSONResponse) VisitGetNodeHostnameResponse(w http.ResponseWriter) error
type GetNodeHostnameRequestObject ¶
type GetNodeHostnameRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeHostnameResponseObject ¶
type GetNodeHostnameResponseObject interface {
VisitGetNodeHostnameResponse(w http.ResponseWriter) error
}
type GetNodeLoad200JSONResponse ¶
type GetNodeLoad200JSONResponse LoadCollectionResponse
func (GetNodeLoad200JSONResponse) VisitGetNodeLoadResponse ¶
func (response GetNodeLoad200JSONResponse) VisitGetNodeLoadResponse(w http.ResponseWriter) error
type GetNodeLoad400JSONResponse ¶
type GetNodeLoad400JSONResponse externalRef0.ErrorResponse
func (GetNodeLoad400JSONResponse) VisitGetNodeLoadResponse ¶
func (response GetNodeLoad400JSONResponse) VisitGetNodeLoadResponse(w http.ResponseWriter) error
type GetNodeLoad401JSONResponse ¶
type GetNodeLoad401JSONResponse externalRef0.ErrorResponse
func (GetNodeLoad401JSONResponse) VisitGetNodeLoadResponse ¶
func (response GetNodeLoad401JSONResponse) VisitGetNodeLoadResponse(w http.ResponseWriter) error
type GetNodeLoad403JSONResponse ¶
type GetNodeLoad403JSONResponse externalRef0.ErrorResponse
func (GetNodeLoad403JSONResponse) VisitGetNodeLoadResponse ¶
func (response GetNodeLoad403JSONResponse) VisitGetNodeLoadResponse(w http.ResponseWriter) error
type GetNodeLoad500JSONResponse ¶
type GetNodeLoad500JSONResponse externalRef0.ErrorResponse
func (GetNodeLoad500JSONResponse) VisitGetNodeLoadResponse ¶
func (response GetNodeLoad500JSONResponse) VisitGetNodeLoadResponse(w http.ResponseWriter) error
type GetNodeLoadRequestObject ¶
type GetNodeLoadRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeLoadResponseObject ¶
type GetNodeLoadResponseObject interface {
VisitGetNodeLoadResponse(w http.ResponseWriter) error
}
type GetNodeMemory200JSONResponse ¶
type GetNodeMemory200JSONResponse MemoryCollectionResponse
func (GetNodeMemory200JSONResponse) VisitGetNodeMemoryResponse ¶
func (response GetNodeMemory200JSONResponse) VisitGetNodeMemoryResponse(w http.ResponseWriter) error
type GetNodeMemory400JSONResponse ¶
type GetNodeMemory400JSONResponse externalRef0.ErrorResponse
func (GetNodeMemory400JSONResponse) VisitGetNodeMemoryResponse ¶
func (response GetNodeMemory400JSONResponse) VisitGetNodeMemoryResponse(w http.ResponseWriter) error
type GetNodeMemory401JSONResponse ¶
type GetNodeMemory401JSONResponse externalRef0.ErrorResponse
func (GetNodeMemory401JSONResponse) VisitGetNodeMemoryResponse ¶
func (response GetNodeMemory401JSONResponse) VisitGetNodeMemoryResponse(w http.ResponseWriter) error
type GetNodeMemory403JSONResponse ¶
type GetNodeMemory403JSONResponse externalRef0.ErrorResponse
func (GetNodeMemory403JSONResponse) VisitGetNodeMemoryResponse ¶
func (response GetNodeMemory403JSONResponse) VisitGetNodeMemoryResponse(w http.ResponseWriter) error
type GetNodeMemory500JSONResponse ¶
type GetNodeMemory500JSONResponse externalRef0.ErrorResponse
func (GetNodeMemory500JSONResponse) VisitGetNodeMemoryResponse ¶
func (response GetNodeMemory500JSONResponse) VisitGetNodeMemoryResponse(w http.ResponseWriter) error
type GetNodeMemoryRequestObject ¶
type GetNodeMemoryRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeMemoryResponseObject ¶
type GetNodeMemoryResponseObject interface {
VisitGetNodeMemoryResponse(w http.ResponseWriter) error
}
type GetNodeNetworkDNSByInterface200JSONResponse ¶
type GetNodeNetworkDNSByInterface200JSONResponse DNSConfigCollectionResponse
func (GetNodeNetworkDNSByInterface200JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse ¶
func (response GetNodeNetworkDNSByInterface200JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
type GetNodeNetworkDNSByInterface400JSONResponse ¶
type GetNodeNetworkDNSByInterface400JSONResponse externalRef0.ErrorResponse
func (GetNodeNetworkDNSByInterface400JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse ¶
func (response GetNodeNetworkDNSByInterface400JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
type GetNodeNetworkDNSByInterface401JSONResponse ¶
type GetNodeNetworkDNSByInterface401JSONResponse externalRef0.ErrorResponse
func (GetNodeNetworkDNSByInterface401JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse ¶
func (response GetNodeNetworkDNSByInterface401JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
type GetNodeNetworkDNSByInterface403JSONResponse ¶
type GetNodeNetworkDNSByInterface403JSONResponse externalRef0.ErrorResponse
func (GetNodeNetworkDNSByInterface403JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse ¶
func (response GetNodeNetworkDNSByInterface403JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
type GetNodeNetworkDNSByInterface500JSONResponse ¶
type GetNodeNetworkDNSByInterface500JSONResponse externalRef0.ErrorResponse
func (GetNodeNetworkDNSByInterface500JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse ¶
func (response GetNodeNetworkDNSByInterface500JSONResponse) VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
type GetNodeNetworkDNSByInterfaceResponseObject ¶
type GetNodeNetworkDNSByInterfaceResponseObject interface {
VisitGetNodeNetworkDNSByInterfaceResponse(w http.ResponseWriter) error
}
type GetNodeOS200JSONResponse ¶
type GetNodeOS200JSONResponse OSInfoCollectionResponse
func (GetNodeOS200JSONResponse) VisitGetNodeOSResponse ¶
func (response GetNodeOS200JSONResponse) VisitGetNodeOSResponse(w http.ResponseWriter) error
type GetNodeOS400JSONResponse ¶
type GetNodeOS400JSONResponse externalRef0.ErrorResponse
func (GetNodeOS400JSONResponse) VisitGetNodeOSResponse ¶
func (response GetNodeOS400JSONResponse) VisitGetNodeOSResponse(w http.ResponseWriter) error
type GetNodeOS401JSONResponse ¶
type GetNodeOS401JSONResponse externalRef0.ErrorResponse
func (GetNodeOS401JSONResponse) VisitGetNodeOSResponse ¶
func (response GetNodeOS401JSONResponse) VisitGetNodeOSResponse(w http.ResponseWriter) error
type GetNodeOS403JSONResponse ¶
type GetNodeOS403JSONResponse externalRef0.ErrorResponse
func (GetNodeOS403JSONResponse) VisitGetNodeOSResponse ¶
func (response GetNodeOS403JSONResponse) VisitGetNodeOSResponse(w http.ResponseWriter) error
type GetNodeOS500JSONResponse ¶
type GetNodeOS500JSONResponse externalRef0.ErrorResponse
func (GetNodeOS500JSONResponse) VisitGetNodeOSResponse ¶
func (response GetNodeOS500JSONResponse) VisitGetNodeOSResponse(w http.ResponseWriter) error
type GetNodeOSRequestObject ¶
type GetNodeOSRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeOSResponseObject ¶
type GetNodeOSResponseObject interface {
VisitGetNodeOSResponse(w http.ResponseWriter) error
}
type GetNodeStatus200JSONResponse ¶
type GetNodeStatus200JSONResponse NodeStatusCollectionResponse
func (GetNodeStatus200JSONResponse) VisitGetNodeStatusResponse ¶
func (response GetNodeStatus200JSONResponse) VisitGetNodeStatusResponse(w http.ResponseWriter) error
type GetNodeStatus400JSONResponse ¶
type GetNodeStatus400JSONResponse externalRef0.ErrorResponse
func (GetNodeStatus400JSONResponse) VisitGetNodeStatusResponse ¶
func (response GetNodeStatus400JSONResponse) VisitGetNodeStatusResponse(w http.ResponseWriter) error
type GetNodeStatus401JSONResponse ¶
type GetNodeStatus401JSONResponse externalRef0.ErrorResponse
func (GetNodeStatus401JSONResponse) VisitGetNodeStatusResponse ¶
func (response GetNodeStatus401JSONResponse) VisitGetNodeStatusResponse(w http.ResponseWriter) error
type GetNodeStatus403JSONResponse ¶
type GetNodeStatus403JSONResponse externalRef0.ErrorResponse
func (GetNodeStatus403JSONResponse) VisitGetNodeStatusResponse ¶
func (response GetNodeStatus403JSONResponse) VisitGetNodeStatusResponse(w http.ResponseWriter) error
type GetNodeStatus500JSONResponse ¶
type GetNodeStatus500JSONResponse externalRef0.ErrorResponse
func (GetNodeStatus500JSONResponse) VisitGetNodeStatusResponse ¶
func (response GetNodeStatus500JSONResponse) VisitGetNodeStatusResponse(w http.ResponseWriter) error
type GetNodeStatusRequestObject ¶
type GetNodeStatusRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeStatusResponseObject ¶
type GetNodeStatusResponseObject interface {
VisitGetNodeStatusResponse(w http.ResponseWriter) error
}
type GetNodeUptime200JSONResponse ¶
type GetNodeUptime200JSONResponse UptimeCollectionResponse
func (GetNodeUptime200JSONResponse) VisitGetNodeUptimeResponse ¶
func (response GetNodeUptime200JSONResponse) VisitGetNodeUptimeResponse(w http.ResponseWriter) error
type GetNodeUptime400JSONResponse ¶
type GetNodeUptime400JSONResponse externalRef0.ErrorResponse
func (GetNodeUptime400JSONResponse) VisitGetNodeUptimeResponse ¶
func (response GetNodeUptime400JSONResponse) VisitGetNodeUptimeResponse(w http.ResponseWriter) error
type GetNodeUptime401JSONResponse ¶
type GetNodeUptime401JSONResponse externalRef0.ErrorResponse
func (GetNodeUptime401JSONResponse) VisitGetNodeUptimeResponse ¶
func (response GetNodeUptime401JSONResponse) VisitGetNodeUptimeResponse(w http.ResponseWriter) error
type GetNodeUptime403JSONResponse ¶
type GetNodeUptime403JSONResponse externalRef0.ErrorResponse
func (GetNodeUptime403JSONResponse) VisitGetNodeUptimeResponse ¶
func (response GetNodeUptime403JSONResponse) VisitGetNodeUptimeResponse(w http.ResponseWriter) error
type GetNodeUptime500JSONResponse ¶
type GetNodeUptime500JSONResponse externalRef0.ErrorResponse
func (GetNodeUptime500JSONResponse) VisitGetNodeUptimeResponse ¶
func (response GetNodeUptime500JSONResponse) VisitGetNodeUptimeResponse(w http.ResponseWriter) error
type GetNodeUptimeRequestObject ¶
type GetNodeUptimeRequestObject struct {
Hostname Hostname `json:"hostname"`
}
type GetNodeUptimeResponseObject ¶
type GetNodeUptimeResponseObject interface {
VisitGetNodeUptimeResponse(w http.ResponseWriter) error
}
type HostnameCollectionResponse ¶
type HostnameCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []HostnameResponse `json:"results"`
}
HostnameCollectionResponse defines model for HostnameCollectionResponse.
type HostnameResponse ¶
type HostnameResponse struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The system's hostname.
Hostname string `json:"hostname"`
// Labels Key-value labels configured on the agent.
Labels *map[string]string `json:"labels,omitempty"`
}
HostnameResponse The hostname of the system.
type LoadAverageResponse ¶
type LoadAverageResponse struct {
// N15min Load average for the last 15 minutes.
N15min float32 `json:"15min"`
// N1min Load average for the last 1 minute.
N1min float32 `json:"1min"`
// N5min Load average for the last 5 minutes.
N5min float32 `json:"5min"`
}
LoadAverageResponse The system load averages for 1, 5, and 15 minutes.
type LoadCollectionResponse ¶
type LoadCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []LoadResultItem `json:"results"`
}
LoadCollectionResponse defines model for LoadCollectionResponse.
type LoadResultItem ¶
type LoadResultItem struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent.
Hostname string `json:"hostname"`
// LoadAverage The system load averages for 1, 5, and 15 minutes.
LoadAverage *LoadAverageResponse `json:"load_average,omitempty"`
}
LoadResultItem defines model for LoadResultItem.
type MemoryCollectionResponse ¶
type MemoryCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []MemoryResultItem `json:"results"`
}
MemoryCollectionResponse defines model for MemoryCollectionResponse.
type MemoryResponse ¶
type MemoryResponse struct {
// Free Free memory in bytes.
Free int `json:"free"`
// Total Total memory in bytes.
Total int `json:"total"`
// Used Used memory in bytes.
Used int `json:"used"`
}
MemoryResponse Memory usage information.
type MemoryResultItem ¶
type MemoryResultItem struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent.
Hostname string `json:"hostname"`
// Memory Memory usage information.
Memory *MemoryResponse `json:"memory,omitempty"`
}
MemoryResultItem defines model for MemoryResultItem.
type NodeStatusCollectionResponse ¶
type NodeStatusCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []NodeStatusResponse `json:"results"`
}
NodeStatusCollectionResponse defines model for NodeStatusCollectionResponse.
type NodeStatusResponse ¶
type NodeStatusResponse struct {
// Disks List of local disk usage information.
Disks *DisksResponse `json:"disks,omitempty"`
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the system.
Hostname string `json:"hostname"`
// LoadAverage The system load averages for 1, 5, and 15 minutes.
LoadAverage *LoadAverageResponse `json:"load_average,omitempty"`
// Memory Memory usage information.
Memory *MemoryResponse `json:"memory,omitempty"`
// OsInfo Operating system information.
OsInfo *OSInfoResponse `json:"os_info,omitempty"`
// Uptime The uptime of the system.
Uptime *string `json:"uptime,omitempty"`
}
NodeStatusResponse defines model for NodeStatusResponse.
type OSInfoCollectionResponse ¶
type OSInfoCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []OSInfoResultItem `json:"results"`
}
OSInfoCollectionResponse defines model for OSInfoCollectionResponse.
type OSInfoResponse ¶
type OSInfoResponse struct {
// Distribution The name of the Linux distribution.
Distribution string `json:"distribution"`
// Version The version of the Linux distribution.
Version string `json:"version"`
}
OSInfoResponse Operating system information.
type OSInfoResultItem ¶
type OSInfoResultItem struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent.
Hostname string `json:"hostname"`
// OsInfo Operating system information.
OsInfo *OSInfoResponse `json:"os_info,omitempty"`
}
OSInfoResultItem defines model for OSInfoResultItem.
type PingCollectionResponse ¶
type PingCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []PingResponse `json:"results"`
}
PingCollectionResponse defines model for PingCollectionResponse.
type PingResponse ¶
type PingResponse struct {
// AvgRtt Average round-trip time in Go time.Duration format.
AvgRtt *string `json:"avg_rtt,omitempty"`
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent that executed the ping.
Hostname string `json:"hostname"`
// MaxRtt Maximum round-trip time in Go time.Duration format.
MaxRtt *string `json:"max_rtt,omitempty"`
// MinRtt Minimum round-trip time in Go time.Duration format.
MinRtt *string `json:"min_rtt,omitempty"`
// PacketLoss Percentage of packet loss.
PacketLoss *float64 `json:"packet_loss,omitempty"`
// PacketsReceived Number of packets received.
PacketsReceived *int `json:"packets_received,omitempty"`
// PacketsSent Number of packets sent.
PacketsSent *int `json:"packets_sent,omitempty"`
}
PingResponse defines model for PingResponse.
type PostNodeCommandExec202JSONResponse ¶
type PostNodeCommandExec202JSONResponse CommandResultCollectionResponse
func (PostNodeCommandExec202JSONResponse) VisitPostNodeCommandExecResponse ¶
func (response PostNodeCommandExec202JSONResponse) VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
type PostNodeCommandExec400JSONResponse ¶
type PostNodeCommandExec400JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandExec400JSONResponse) VisitPostNodeCommandExecResponse ¶
func (response PostNodeCommandExec400JSONResponse) VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
type PostNodeCommandExec401JSONResponse ¶
type PostNodeCommandExec401JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandExec401JSONResponse) VisitPostNodeCommandExecResponse ¶
func (response PostNodeCommandExec401JSONResponse) VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
type PostNodeCommandExec403JSONResponse ¶
type PostNodeCommandExec403JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandExec403JSONResponse) VisitPostNodeCommandExecResponse ¶
func (response PostNodeCommandExec403JSONResponse) VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
type PostNodeCommandExec500JSONResponse ¶
type PostNodeCommandExec500JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandExec500JSONResponse) VisitPostNodeCommandExecResponse ¶
func (response PostNodeCommandExec500JSONResponse) VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
type PostNodeCommandExecJSONRequestBody ¶
type PostNodeCommandExecJSONRequestBody = CommandExecRequest
PostNodeCommandExecJSONRequestBody defines body for PostNodeCommandExec for application/json ContentType.
type PostNodeCommandExecRequestObject ¶
type PostNodeCommandExecRequestObject struct {
Hostname Hostname `json:"hostname"`
Body *PostNodeCommandExecJSONRequestBody
}
type PostNodeCommandExecResponseObject ¶
type PostNodeCommandExecResponseObject interface {
VisitPostNodeCommandExecResponse(w http.ResponseWriter) error
}
type PostNodeCommandShell202JSONResponse ¶
type PostNodeCommandShell202JSONResponse CommandResultCollectionResponse
func (PostNodeCommandShell202JSONResponse) VisitPostNodeCommandShellResponse ¶
func (response PostNodeCommandShell202JSONResponse) VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
type PostNodeCommandShell400JSONResponse ¶
type PostNodeCommandShell400JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandShell400JSONResponse) VisitPostNodeCommandShellResponse ¶
func (response PostNodeCommandShell400JSONResponse) VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
type PostNodeCommandShell401JSONResponse ¶
type PostNodeCommandShell401JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandShell401JSONResponse) VisitPostNodeCommandShellResponse ¶
func (response PostNodeCommandShell401JSONResponse) VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
type PostNodeCommandShell403JSONResponse ¶
type PostNodeCommandShell403JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandShell403JSONResponse) VisitPostNodeCommandShellResponse ¶
func (response PostNodeCommandShell403JSONResponse) VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
type PostNodeCommandShell500JSONResponse ¶
type PostNodeCommandShell500JSONResponse externalRef0.ErrorResponse
func (PostNodeCommandShell500JSONResponse) VisitPostNodeCommandShellResponse ¶
func (response PostNodeCommandShell500JSONResponse) VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
type PostNodeCommandShellJSONRequestBody ¶
type PostNodeCommandShellJSONRequestBody = CommandShellRequest
PostNodeCommandShellJSONRequestBody defines body for PostNodeCommandShell for application/json ContentType.
type PostNodeCommandShellRequestObject ¶
type PostNodeCommandShellRequestObject struct {
Hostname Hostname `json:"hostname"`
Body *PostNodeCommandShellJSONRequestBody
}
type PostNodeCommandShellResponseObject ¶
type PostNodeCommandShellResponseObject interface {
VisitPostNodeCommandShellResponse(w http.ResponseWriter) error
}
type PostNodeNetworkPing200JSONResponse ¶
type PostNodeNetworkPing200JSONResponse PingCollectionResponse
func (PostNodeNetworkPing200JSONResponse) VisitPostNodeNetworkPingResponse ¶
func (response PostNodeNetworkPing200JSONResponse) VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
type PostNodeNetworkPing400JSONResponse ¶
type PostNodeNetworkPing400JSONResponse externalRef0.ErrorResponse
func (PostNodeNetworkPing400JSONResponse) VisitPostNodeNetworkPingResponse ¶
func (response PostNodeNetworkPing400JSONResponse) VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
type PostNodeNetworkPing401JSONResponse ¶
type PostNodeNetworkPing401JSONResponse externalRef0.ErrorResponse
func (PostNodeNetworkPing401JSONResponse) VisitPostNodeNetworkPingResponse ¶
func (response PostNodeNetworkPing401JSONResponse) VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
type PostNodeNetworkPing403JSONResponse ¶
type PostNodeNetworkPing403JSONResponse externalRef0.ErrorResponse
func (PostNodeNetworkPing403JSONResponse) VisitPostNodeNetworkPingResponse ¶
func (response PostNodeNetworkPing403JSONResponse) VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
type PostNodeNetworkPing500JSONResponse ¶
type PostNodeNetworkPing500JSONResponse externalRef0.ErrorResponse
func (PostNodeNetworkPing500JSONResponse) VisitPostNodeNetworkPingResponse ¶
func (response PostNodeNetworkPing500JSONResponse) VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
type PostNodeNetworkPingJSONBody ¶
type PostNodeNetworkPingJSONBody struct {
// Address The IP address of the server to ping. Supports both IPv4 and IPv6.
Address string `json:"address" validate:"required,ip"`
}
PostNodeNetworkPingJSONBody defines parameters for PostNodeNetworkPing.
type PostNodeNetworkPingJSONRequestBody ¶
type PostNodeNetworkPingJSONRequestBody PostNodeNetworkPingJSONBody
PostNodeNetworkPingJSONRequestBody defines body for PostNodeNetworkPing for application/json ContentType.
type PostNodeNetworkPingRequestObject ¶
type PostNodeNetworkPingRequestObject struct {
Hostname Hostname `json:"hostname"`
Body *PostNodeNetworkPingJSONRequestBody
}
type PostNodeNetworkPingResponseObject ¶
type PostNodeNetworkPingResponseObject interface {
VisitPostNodeNetworkPingResponse(w http.ResponseWriter) error
}
type PutNodeNetworkDNS202JSONResponse ¶
type PutNodeNetworkDNS202JSONResponse DNSUpdateCollectionResponse
func (PutNodeNetworkDNS202JSONResponse) VisitPutNodeNetworkDNSResponse ¶
func (response PutNodeNetworkDNS202JSONResponse) VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
type PutNodeNetworkDNS400JSONResponse ¶
type PutNodeNetworkDNS400JSONResponse externalRef0.ErrorResponse
func (PutNodeNetworkDNS400JSONResponse) VisitPutNodeNetworkDNSResponse ¶
func (response PutNodeNetworkDNS400JSONResponse) VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
type PutNodeNetworkDNS401JSONResponse ¶
type PutNodeNetworkDNS401JSONResponse externalRef0.ErrorResponse
func (PutNodeNetworkDNS401JSONResponse) VisitPutNodeNetworkDNSResponse ¶
func (response PutNodeNetworkDNS401JSONResponse) VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
type PutNodeNetworkDNS403JSONResponse ¶
type PutNodeNetworkDNS403JSONResponse externalRef0.ErrorResponse
func (PutNodeNetworkDNS403JSONResponse) VisitPutNodeNetworkDNSResponse ¶
func (response PutNodeNetworkDNS403JSONResponse) VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
type PutNodeNetworkDNS500JSONResponse ¶
type PutNodeNetworkDNS500JSONResponse externalRef0.ErrorResponse
func (PutNodeNetworkDNS500JSONResponse) VisitPutNodeNetworkDNSResponse ¶
func (response PutNodeNetworkDNS500JSONResponse) VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
type PutNodeNetworkDNSJSONRequestBody ¶
type PutNodeNetworkDNSJSONRequestBody = DNSConfigUpdateRequest
PutNodeNetworkDNSJSONRequestBody defines body for PutNodeNetworkDNS for application/json ContentType.
type PutNodeNetworkDNSRequestObject ¶
type PutNodeNetworkDNSRequestObject struct {
Hostname Hostname `json:"hostname"`
Body *PutNodeNetworkDNSJSONRequestBody
}
type PutNodeNetworkDNSResponseObject ¶
type PutNodeNetworkDNSResponseObject interface {
VisitPutNodeNetworkDNSResponse(w http.ResponseWriter) error
}
type ServerInterface ¶
type ServerInterface interface {
// Retrieve node status
// (GET /node/{hostname})
GetNodeStatus(ctx echo.Context, hostname Hostname) error
// Execute a command
// (POST /node/{hostname}/command/exec)
PostNodeCommandExec(ctx echo.Context, hostname Hostname) error
// Execute a shell command
// (POST /node/{hostname}/command/shell)
PostNodeCommandShell(ctx echo.Context, hostname Hostname) error
// Retrieve disk usage
// (GET /node/{hostname}/disk)
GetNodeDisk(ctx echo.Context, hostname Hostname) error
// Retrieve node hostname
// (GET /node/{hostname}/hostname)
GetNodeHostname(ctx echo.Context, hostname Hostname) error
// Retrieve load averages
// (GET /node/{hostname}/load)
GetNodeLoad(ctx echo.Context, hostname Hostname) error
// Retrieve memory stats
// (GET /node/{hostname}/memory)
GetNodeMemory(ctx echo.Context, hostname Hostname) error
// Update DNS servers
// (PUT /node/{hostname}/network/dns)
PutNodeNetworkDNS(ctx echo.Context, hostname Hostname) error
// List DNS servers
// (GET /node/{hostname}/network/dns/{interfaceName})
GetNodeNetworkDNSByInterface(ctx echo.Context, hostname Hostname, interfaceName string) error
// Ping a remote server
// (POST /node/{hostname}/network/ping)
PostNodeNetworkPing(ctx echo.Context, hostname Hostname) error
// Retrieve OS info
// (GET /node/{hostname}/os)
GetNodeOS(ctx echo.Context, hostname Hostname) error
// Retrieve uptime
// (GET /node/{hostname}/uptime)
GetNodeUptime(ctx echo.Context, hostname Hostname) error
}
ServerInterface represents all server handlers.
func NewStrictHandler ¶
func NewStrictHandler(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc) ServerInterface
type ServerInterfaceWrapper ¶
type ServerInterfaceWrapper struct {
Handler ServerInterface
}
ServerInterfaceWrapper converts echo contexts to parameters.
func (*ServerInterfaceWrapper) GetNodeDisk ¶
func (w *ServerInterfaceWrapper) GetNodeDisk(ctx echo.Context) error
GetNodeDisk converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeHostname ¶
func (w *ServerInterfaceWrapper) GetNodeHostname(ctx echo.Context) error
GetNodeHostname converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeLoad ¶
func (w *ServerInterfaceWrapper) GetNodeLoad(ctx echo.Context) error
GetNodeLoad converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeMemory ¶
func (w *ServerInterfaceWrapper) GetNodeMemory(ctx echo.Context) error
GetNodeMemory converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeNetworkDNSByInterface ¶
func (w *ServerInterfaceWrapper) GetNodeNetworkDNSByInterface(ctx echo.Context) error
GetNodeNetworkDNSByInterface converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeOS ¶
func (w *ServerInterfaceWrapper) GetNodeOS(ctx echo.Context) error
GetNodeOS converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeStatus ¶
func (w *ServerInterfaceWrapper) GetNodeStatus(ctx echo.Context) error
GetNodeStatus converts echo context to params.
func (*ServerInterfaceWrapper) GetNodeUptime ¶
func (w *ServerInterfaceWrapper) GetNodeUptime(ctx echo.Context) error
GetNodeUptime converts echo context to params.
func (*ServerInterfaceWrapper) PostNodeCommandExec ¶
func (w *ServerInterfaceWrapper) PostNodeCommandExec(ctx echo.Context) error
PostNodeCommandExec converts echo context to params.
func (*ServerInterfaceWrapper) PostNodeCommandShell ¶
func (w *ServerInterfaceWrapper) PostNodeCommandShell(ctx echo.Context) error
PostNodeCommandShell converts echo context to params.
func (*ServerInterfaceWrapper) PostNodeNetworkPing ¶
func (w *ServerInterfaceWrapper) PostNodeNetworkPing(ctx echo.Context) error
PostNodeNetworkPing converts echo context to params.
func (*ServerInterfaceWrapper) PutNodeNetworkDNS ¶
func (w *ServerInterfaceWrapper) PutNodeNetworkDNS(ctx echo.Context) error
PutNodeNetworkDNS converts echo context to params.
type StrictHandlerFunc ¶
type StrictHandlerFunc = strictecho.StrictEchoHandlerFunc
type StrictMiddlewareFunc ¶
type StrictMiddlewareFunc = strictecho.StrictEchoMiddlewareFunc
type StrictServerInterface ¶
type StrictServerInterface interface {
// Retrieve node status
// (GET /node/{hostname})
GetNodeStatus(ctx context.Context, request GetNodeStatusRequestObject) (GetNodeStatusResponseObject, error)
// Execute a command
// (POST /node/{hostname}/command/exec)
PostNodeCommandExec(ctx context.Context, request PostNodeCommandExecRequestObject) (PostNodeCommandExecResponseObject, error)
// Execute a shell command
// (POST /node/{hostname}/command/shell)
PostNodeCommandShell(ctx context.Context, request PostNodeCommandShellRequestObject) (PostNodeCommandShellResponseObject, error)
// Retrieve disk usage
// (GET /node/{hostname}/disk)
GetNodeDisk(ctx context.Context, request GetNodeDiskRequestObject) (GetNodeDiskResponseObject, error)
// Retrieve node hostname
// (GET /node/{hostname}/hostname)
GetNodeHostname(ctx context.Context, request GetNodeHostnameRequestObject) (GetNodeHostnameResponseObject, error)
// Retrieve load averages
// (GET /node/{hostname}/load)
GetNodeLoad(ctx context.Context, request GetNodeLoadRequestObject) (GetNodeLoadResponseObject, error)
// Retrieve memory stats
// (GET /node/{hostname}/memory)
GetNodeMemory(ctx context.Context, request GetNodeMemoryRequestObject) (GetNodeMemoryResponseObject, error)
// Update DNS servers
// (PUT /node/{hostname}/network/dns)
PutNodeNetworkDNS(ctx context.Context, request PutNodeNetworkDNSRequestObject) (PutNodeNetworkDNSResponseObject, error)
// List DNS servers
// (GET /node/{hostname}/network/dns/{interfaceName})
GetNodeNetworkDNSByInterface(ctx context.Context, request GetNodeNetworkDNSByInterfaceRequestObject) (GetNodeNetworkDNSByInterfaceResponseObject, error)
// Ping a remote server
// (POST /node/{hostname}/network/ping)
PostNodeNetworkPing(ctx context.Context, request PostNodeNetworkPingRequestObject) (PostNodeNetworkPingResponseObject, error)
// Retrieve OS info
// (GET /node/{hostname}/os)
GetNodeOS(ctx context.Context, request GetNodeOSRequestObject) (GetNodeOSResponseObject, error)
// Retrieve uptime
// (GET /node/{hostname}/uptime)
GetNodeUptime(ctx context.Context, request GetNodeUptimeRequestObject) (GetNodeUptimeResponseObject, error)
}
StrictServerInterface represents all server handlers.
type UptimeCollectionResponse ¶
type UptimeCollectionResponse struct {
// JobId The job ID used to process this request.
JobId *openapi_types.UUID `json:"job_id,omitempty"`
Results []UptimeResponse `json:"results"`
}
UptimeCollectionResponse defines model for UptimeCollectionResponse.
type UptimeResponse ¶
type UptimeResponse struct {
// Error Error message if the agent failed.
Error *string `json:"error,omitempty"`
// Hostname The hostname of the agent.
Hostname string `json:"hostname"`
// Uptime The uptime of the system.
Uptime *string `json:"uptime,omitempty"`
}
UptimeResponse System uptime information.