Documentation
¶
Overview ¶
Package gen provides primitives to interact with the openapi HTTP API.
Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.1 DO NOT EDIT.
Package gen contains generated code for the common API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrorResponse ¶
type ErrorResponse struct {
// Code The error code.
Code *int `json:"code,omitempty"`
// Details Additional details about the error.
Details *string `json:"details,omitempty"`
// Error A description of the error that occurred.
Error *string `json:"error,omitempty"`
}
ErrorResponse defines model for ErrorResponse.
Click to show internal directories.
Click to hide internal directories.