Documentation
¶
Overview ¶
Package log provides log management API handlers.
Index ¶
- func Handler(logger *slog.Logger, jobClient client.JobClient, signingKey string, ...) []func(e *echo.Echo)
- type Log
- func (s *Log) GetNodeLog(ctx context.Context, request gen.GetNodeLogRequestObject) (gen.GetNodeLogResponseObject, error)
- func (s *Log) GetNodeLogSource(ctx context.Context, request gen.GetNodeLogSourceRequestObject) (gen.GetNodeLogSourceResponseObject, error)
- func (s *Log) GetNodeLogUnit(ctx context.Context, request gen.GetNodeLogUnitRequestObject) (gen.GetNodeLogUnitResponseObject, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Log ¶
type Log struct {
// JobClient provides job-based operations for log management.
JobClient client.JobClient
// contains filtered or unexported fields
}
Log implementation of the Log APIs operations.
func (*Log) GetNodeLog ¶
func (s *Log) GetNodeLog( ctx context.Context, request gen.GetNodeLogRequestObject, ) (gen.GetNodeLogResponseObject, error)
GetNodeLog returns system log entries from a target node.
func (*Log) GetNodeLogSource ¶
func (s *Log) GetNodeLogSource( ctx context.Context, request gen.GetNodeLogSourceRequestObject, ) (gen.GetNodeLogSourceResponseObject, error)
GetNodeLogSource returns unique syslog identifiers from a target node.
func (*Log) GetNodeLogUnit ¶
func (s *Log) GetNodeLogUnit( ctx context.Context, request gen.GetNodeLogUnitRequestObject, ) (gen.GetNodeLogUnitResponseObject, error)
GetNodeLogUnit returns log entries for a specific systemd unit from a target node.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.