packageapi

package
v0.0.0-...-36c55c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package packageapi provides package-management-related API handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handler

func Handler(
	logger *slog.Logger,
	jobClient client.JobClient,
	signingKey string,
	customRoles map[string][]string,
) []func(e *echo.Echo)

Handler returns Package route registration functions.

Types

type Package

type Package struct {
	// JobClient provides job-based operations for package management.
	JobClient client.JobClient
	// contains filtered or unexported fields
}

Package implementation of the Package APIs operations.

func New

func New(
	logger *slog.Logger,
	jobClient client.JobClient,
) *Package

New factory to create a new instance.

func (*Package) DeleteNodePackage

DeleteNodePackage removes a package from a target node.

func (*Package) GetNodePackage

GetNodePackage lists all installed packages on a target node.

func (*Package) GetNodePackageByName

GetNodePackageByName gets a single package by name on a target node.

func (*Package) GetNodePackageUpdate

GetNodePackageUpdate lists available package updates on a target node.

func (*Package) PostNodePackage

PostNodePackage installs a package on a target node.

func (*Package) PostNodePackageUpdate

PostNodePackageUpdate refreshes package sources on a target node.

Directories

Path Synopsis
Package gen contains generated code for the package management API.
Package gen contains generated code for the package management API.

Jump to