process

package
v0.0.0-...-8513156 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package process provides process management API handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handler

func Handler(
	logger *slog.Logger,
	jobClient client.JobClient,
	signingKey string,
	customRoles map[string][]string,
) []func(e *echo.Echo)

Handler returns Process route registration functions.

Types

type Process

type Process struct {
	// JobClient provides job-based operations for process management.
	JobClient client.JobClient
	// contains filtered or unexported fields
}

Process implementation of the Process APIs operations.

func New

func New(
	logger *slog.Logger,
	jobClient client.JobClient,
) *Process

New factory to create a new instance.

func (*Process) GetNodeProcess

GetNodeProcess lists processes on a target node.

func (*Process) GetNodeProcessByPid

GetNodeProcessByPid gets a process by PID on a target node.

func (*Process) PostNodeProcessSignal

PostNodeProcessSignal sends a signal to a process on a target node.

Directories

Path Synopsis
Package gen contains generated code for the process API.
Package gen contains generated code for the process API.

Jump to