timezone

package
v0.0.0-...-8513156 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package timezone provides timezone-related API handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handler

func Handler(
	logger *slog.Logger,
	jobClient client.JobClient,
	signingKey string,
	customRoles map[string][]string,
) []func(e *echo.Echo)

Handler returns Timezone route registration functions.

Types

type Timezone

type Timezone struct {
	// JobClient provides job-based operations for timezone management.
	JobClient client.JobClient
	// contains filtered or unexported fields
}

Timezone implementation of the Timezone APIs operations.

func New

func New(
	logger *slog.Logger,
	jobClient client.JobClient,
) *Timezone

New factory to create a new instance.

func (*Timezone) GetNodeTimezone

GetNodeTimezone gets the current system timezone on a target node.

func (*Timezone) PutNodeTimezone

PutNodeTimezone updates the system timezone on a target node.

Directories

Path Synopsis
Package gen contains generated code for the Timezone API.
Package gen contains generated code for the Timezone API.

Jump to