user

package
v0.0.0-...-36c55c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package user provides user and group API handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handler

func Handler(
	logger *slog.Logger,
	jobClient client.JobClient,
	signingKey string,
	customRoles map[string][]string,
) []func(e *echo.Echo)

Handler returns User and Group route registration functions.

Types

type User

type User struct {
	// JobClient provides job-based operations for user and group management.
	JobClient client.JobClient
	// contains filtered or unexported fields
}

User implementation of the User and Group APIs operations.

func New

func New(
	logger *slog.Logger,
	jobClient client.JobClient,
) *User

New factory to create a new instance.

func (*User) DeleteNodeGroup

DeleteNodeGroup deletes a group on a target node.

func (*User) DeleteNodeUser

DeleteNodeUser deletes a user on a target node.

func (*User) DeleteNodeUserSSHKey

DeleteNodeUserSSHKey removes an SSH authorized key by fingerprint for a user on a target node.

func (*User) GetNodeGroup

GetNodeGroup lists all groups on a target node.

func (*User) GetNodeGroupByName

GetNodeGroupByName gets a single group by name on a target node.

func (*User) GetNodeUser

GetNodeUser lists all users on a target node.

func (*User) GetNodeUserByName

GetNodeUserByName gets a single user by name on a target node.

func (*User) GetNodeUserSSHKey

GetNodeUserSSHKey lists SSH authorized keys for a user on a target node.

func (*User) PostNodeGroup

PostNodeGroup creates a group on a target node.

func (*User) PostNodeUser

PostNodeUser creates a user on a target node.

func (*User) PostNodeUserPassword

PostNodeUserPassword changes a user's password on a target node.

func (*User) PostNodeUserSSHKey

PostNodeUserSSHKey adds an SSH authorized key for a user on a target node.

func (*User) PutNodeGroup

PutNodeGroup updates a group on a target node.

func (*User) PutNodeUser

PutNodeUser updates a user on a target node.

Directories

Path Synopsis
Package gen contains generated code for the user and group API.
Package gen contains generated code for the user and group API.

Jump to