gen

package
v0.0.0-...-36c55c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package gen contains generated code for the user and group API.

Package gen provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.1 DO NOT EDIT.

Index

Constants

const (
	BearerAuthScopes = "BearerAuth.Scopes"
)

Variables

This section is empty.

Functions

func RegisterHandlers

func RegisterHandlers(router EchoRouter, si ServerInterface)

RegisterHandlers adds each server route to the EchoRouter.

func RegisterHandlersWithBaseURL

func RegisterHandlersWithBaseURL(router EchoRouter, si ServerInterface, baseURL string)

Registers handlers, and prepends BaseURL to the paths, so that the paths can be served under a prefix.

Types

type DeleteNodeGroup200JSONResponse

type DeleteNodeGroup200JSONResponse GroupMutationResponse

func (DeleteNodeGroup200JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup200JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroup400JSONResponse

type DeleteNodeGroup400JSONResponse externalRef0.ErrorResponse

func (DeleteNodeGroup400JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup400JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroup401JSONResponse

type DeleteNodeGroup401JSONResponse externalRef0.ErrorResponse

func (DeleteNodeGroup401JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup401JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroup403JSONResponse

type DeleteNodeGroup403JSONResponse externalRef0.ErrorResponse

func (DeleteNodeGroup403JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup403JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroup404JSONResponse

type DeleteNodeGroup404JSONResponse externalRef0.ErrorResponse

func (DeleteNodeGroup404JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup404JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroup500JSONResponse

type DeleteNodeGroup500JSONResponse externalRef0.ErrorResponse

func (DeleteNodeGroup500JSONResponse) VisitDeleteNodeGroupResponse

func (response DeleteNodeGroup500JSONResponse) VisitDeleteNodeGroupResponse(w http.ResponseWriter) error

type DeleteNodeGroupRequestObject

type DeleteNodeGroupRequestObject struct {
	Hostname Hostname  `json:"hostname"`
	Name     GroupName `json:"name"`
}

type DeleteNodeGroupResponseObject

type DeleteNodeGroupResponseObject interface {
	VisitDeleteNodeGroupResponse(w http.ResponseWriter) error
}

type DeleteNodeUser200JSONResponse

type DeleteNodeUser200JSONResponse UserMutationResponse

func (DeleteNodeUser200JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser200JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUser400JSONResponse

type DeleteNodeUser400JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUser400JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser400JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUser401JSONResponse

type DeleteNodeUser401JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUser401JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser401JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUser403JSONResponse

type DeleteNodeUser403JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUser403JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser403JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUser404JSONResponse

type DeleteNodeUser404JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUser404JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser404JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUser500JSONResponse

type DeleteNodeUser500JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUser500JSONResponse) VisitDeleteNodeUserResponse

func (response DeleteNodeUser500JSONResponse) VisitDeleteNodeUserResponse(w http.ResponseWriter) error

type DeleteNodeUserRequestObject

type DeleteNodeUserRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
}

type DeleteNodeUserResponseObject

type DeleteNodeUserResponseObject interface {
	VisitDeleteNodeUserResponse(w http.ResponseWriter) error
}

type DeleteNodeUserSSHKey200JSONResponse

type DeleteNodeUserSSHKey200JSONResponse SSHKeyMutationResponse

func (DeleteNodeUserSSHKey200JSONResponse) VisitDeleteNodeUserSSHKeyResponse

func (response DeleteNodeUserSSHKey200JSONResponse) VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error

type DeleteNodeUserSSHKey400JSONResponse

type DeleteNodeUserSSHKey400JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUserSSHKey400JSONResponse) VisitDeleteNodeUserSSHKeyResponse

func (response DeleteNodeUserSSHKey400JSONResponse) VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error

type DeleteNodeUserSSHKey401JSONResponse

type DeleteNodeUserSSHKey401JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUserSSHKey401JSONResponse) VisitDeleteNodeUserSSHKeyResponse

func (response DeleteNodeUserSSHKey401JSONResponse) VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error

type DeleteNodeUserSSHKey403JSONResponse

type DeleteNodeUserSSHKey403JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUserSSHKey403JSONResponse) VisitDeleteNodeUserSSHKeyResponse

func (response DeleteNodeUserSSHKey403JSONResponse) VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error

type DeleteNodeUserSSHKey500JSONResponse

type DeleteNodeUserSSHKey500JSONResponse externalRef0.ErrorResponse

func (DeleteNodeUserSSHKey500JSONResponse) VisitDeleteNodeUserSSHKeyResponse

func (response DeleteNodeUserSSHKey500JSONResponse) VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error

type DeleteNodeUserSSHKeyRequestObject

type DeleteNodeUserSSHKeyRequestObject struct {
	Hostname    Hostname          `json:"hostname"`
	Name        UserName          `json:"name"`
	Fingerprint SSHKeyFingerprint `json:"fingerprint"`
}

type DeleteNodeUserSSHKeyResponseObject

type DeleteNodeUserSSHKeyResponseObject interface {
	VisitDeleteNodeUserSSHKeyResponse(w http.ResponseWriter) error
}

type EchoRouter

type EchoRouter interface {
	CONNECT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	DELETE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	GET(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	HEAD(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	OPTIONS(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	PATCH(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	POST(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	PUT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	TRACE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
}

This is a simple interface which specifies echo.Route addition functions which are present on both echo.Echo and echo.Group, since we want to allow using either of them for path registration

type ErrorResponse

type ErrorResponse = externalRef0.ErrorResponse

ErrorResponse defines model for ErrorResponse.

type GetNodeGroup200JSONResponse

type GetNodeGroup200JSONResponse GroupCollectionResponse

func (GetNodeGroup200JSONResponse) VisitGetNodeGroupResponse

func (response GetNodeGroup200JSONResponse) VisitGetNodeGroupResponse(w http.ResponseWriter) error

type GetNodeGroup400JSONResponse

type GetNodeGroup400JSONResponse externalRef0.ErrorResponse

func (GetNodeGroup400JSONResponse) VisitGetNodeGroupResponse

func (response GetNodeGroup400JSONResponse) VisitGetNodeGroupResponse(w http.ResponseWriter) error

type GetNodeGroup401JSONResponse

type GetNodeGroup401JSONResponse externalRef0.ErrorResponse

func (GetNodeGroup401JSONResponse) VisitGetNodeGroupResponse

func (response GetNodeGroup401JSONResponse) VisitGetNodeGroupResponse(w http.ResponseWriter) error

type GetNodeGroup403JSONResponse

type GetNodeGroup403JSONResponse externalRef0.ErrorResponse

func (GetNodeGroup403JSONResponse) VisitGetNodeGroupResponse

func (response GetNodeGroup403JSONResponse) VisitGetNodeGroupResponse(w http.ResponseWriter) error

type GetNodeGroup500JSONResponse

type GetNodeGroup500JSONResponse externalRef0.ErrorResponse

func (GetNodeGroup500JSONResponse) VisitGetNodeGroupResponse

func (response GetNodeGroup500JSONResponse) VisitGetNodeGroupResponse(w http.ResponseWriter) error

type GetNodeGroupByName200JSONResponse

type GetNodeGroupByName200JSONResponse GroupCollectionResponse

func (GetNodeGroupByName200JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName200JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByName400JSONResponse

type GetNodeGroupByName400JSONResponse externalRef0.ErrorResponse

func (GetNodeGroupByName400JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName400JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByName401JSONResponse

type GetNodeGroupByName401JSONResponse externalRef0.ErrorResponse

func (GetNodeGroupByName401JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName401JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByName403JSONResponse

type GetNodeGroupByName403JSONResponse externalRef0.ErrorResponse

func (GetNodeGroupByName403JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName403JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByName404JSONResponse

type GetNodeGroupByName404JSONResponse externalRef0.ErrorResponse

func (GetNodeGroupByName404JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName404JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByName500JSONResponse

type GetNodeGroupByName500JSONResponse externalRef0.ErrorResponse

func (GetNodeGroupByName500JSONResponse) VisitGetNodeGroupByNameResponse

func (response GetNodeGroupByName500JSONResponse) VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error

type GetNodeGroupByNameRequestObject

type GetNodeGroupByNameRequestObject struct {
	Hostname Hostname  `json:"hostname"`
	Name     GroupName `json:"name"`
}

type GetNodeGroupByNameResponseObject

type GetNodeGroupByNameResponseObject interface {
	VisitGetNodeGroupByNameResponse(w http.ResponseWriter) error
}

type GetNodeGroupRequestObject

type GetNodeGroupRequestObject struct {
	Hostname Hostname `json:"hostname"`
}

type GetNodeGroupResponseObject

type GetNodeGroupResponseObject interface {
	VisitGetNodeGroupResponse(w http.ResponseWriter) error
}

type GetNodeUser200JSONResponse

type GetNodeUser200JSONResponse UserCollectionResponse

func (GetNodeUser200JSONResponse) VisitGetNodeUserResponse

func (response GetNodeUser200JSONResponse) VisitGetNodeUserResponse(w http.ResponseWriter) error

type GetNodeUser400JSONResponse

type GetNodeUser400JSONResponse externalRef0.ErrorResponse

func (GetNodeUser400JSONResponse) VisitGetNodeUserResponse

func (response GetNodeUser400JSONResponse) VisitGetNodeUserResponse(w http.ResponseWriter) error

type GetNodeUser401JSONResponse

type GetNodeUser401JSONResponse externalRef0.ErrorResponse

func (GetNodeUser401JSONResponse) VisitGetNodeUserResponse

func (response GetNodeUser401JSONResponse) VisitGetNodeUserResponse(w http.ResponseWriter) error

type GetNodeUser403JSONResponse

type GetNodeUser403JSONResponse externalRef0.ErrorResponse

func (GetNodeUser403JSONResponse) VisitGetNodeUserResponse

func (response GetNodeUser403JSONResponse) VisitGetNodeUserResponse(w http.ResponseWriter) error

type GetNodeUser500JSONResponse

type GetNodeUser500JSONResponse externalRef0.ErrorResponse

func (GetNodeUser500JSONResponse) VisitGetNodeUserResponse

func (response GetNodeUser500JSONResponse) VisitGetNodeUserResponse(w http.ResponseWriter) error

type GetNodeUserByName200JSONResponse

type GetNodeUserByName200JSONResponse UserCollectionResponse

func (GetNodeUserByName200JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName200JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByName400JSONResponse

type GetNodeUserByName400JSONResponse externalRef0.ErrorResponse

func (GetNodeUserByName400JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName400JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByName401JSONResponse

type GetNodeUserByName401JSONResponse externalRef0.ErrorResponse

func (GetNodeUserByName401JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName401JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByName403JSONResponse

type GetNodeUserByName403JSONResponse externalRef0.ErrorResponse

func (GetNodeUserByName403JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName403JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByName404JSONResponse

type GetNodeUserByName404JSONResponse externalRef0.ErrorResponse

func (GetNodeUserByName404JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName404JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByName500JSONResponse

type GetNodeUserByName500JSONResponse externalRef0.ErrorResponse

func (GetNodeUserByName500JSONResponse) VisitGetNodeUserByNameResponse

func (response GetNodeUserByName500JSONResponse) VisitGetNodeUserByNameResponse(w http.ResponseWriter) error

type GetNodeUserByNameRequestObject

type GetNodeUserByNameRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
}

type GetNodeUserByNameResponseObject

type GetNodeUserByNameResponseObject interface {
	VisitGetNodeUserByNameResponse(w http.ResponseWriter) error
}

type GetNodeUserRequestObject

type GetNodeUserRequestObject struct {
	Hostname Hostname `json:"hostname"`
}

type GetNodeUserResponseObject

type GetNodeUserResponseObject interface {
	VisitGetNodeUserResponse(w http.ResponseWriter) error
}

type GetNodeUserSSHKey200JSONResponse

type GetNodeUserSSHKey200JSONResponse SSHKeyCollectionResponse

func (GetNodeUserSSHKey200JSONResponse) VisitGetNodeUserSSHKeyResponse

func (response GetNodeUserSSHKey200JSONResponse) VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error

type GetNodeUserSSHKey400JSONResponse

type GetNodeUserSSHKey400JSONResponse externalRef0.ErrorResponse

func (GetNodeUserSSHKey400JSONResponse) VisitGetNodeUserSSHKeyResponse

func (response GetNodeUserSSHKey400JSONResponse) VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error

type GetNodeUserSSHKey401JSONResponse

type GetNodeUserSSHKey401JSONResponse externalRef0.ErrorResponse

func (GetNodeUserSSHKey401JSONResponse) VisitGetNodeUserSSHKeyResponse

func (response GetNodeUserSSHKey401JSONResponse) VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error

type GetNodeUserSSHKey403JSONResponse

type GetNodeUserSSHKey403JSONResponse externalRef0.ErrorResponse

func (GetNodeUserSSHKey403JSONResponse) VisitGetNodeUserSSHKeyResponse

func (response GetNodeUserSSHKey403JSONResponse) VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error

type GetNodeUserSSHKey500JSONResponse

type GetNodeUserSSHKey500JSONResponse externalRef0.ErrorResponse

func (GetNodeUserSSHKey500JSONResponse) VisitGetNodeUserSSHKeyResponse

func (response GetNodeUserSSHKey500JSONResponse) VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error

type GetNodeUserSSHKeyRequestObject

type GetNodeUserSSHKeyRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
}

type GetNodeUserSSHKeyResponseObject

type GetNodeUserSSHKeyResponseObject interface {
	VisitGetNodeUserSSHKeyResponse(w http.ResponseWriter) error
}

type GroupCollectionResponse

type GroupCollectionResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID `json:"job_id,omitempty"`
	Results []GroupEntry        `json:"results"`
}

GroupCollectionResponse defines model for GroupCollectionResponse.

type GroupCreateRequest

type GroupCreateRequest struct {
	// Gid Numeric group ID. If omitted, the system assigns one.
	Gid *int `json:"gid,omitempty" validate:"omitempty,min=0"`

	// Name Group name.
	Name string `json:"name" validate:"required,min=1,max=32"`

	// System Create a system group.
	System *bool `json:"system,omitempty" validate:"omitempty"`
}

GroupCreateRequest defines model for GroupCreateRequest.

type GroupEntry

type GroupEntry struct {
	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Groups Groups on this host.
	Groups *[]GroupInfo `json:"groups,omitempty"`

	// Hostname Hostname of the agent that reported this entry.
	Hostname string `json:"hostname"`

	// Status The status of the operation for this host.
	Status GroupEntryStatus `json:"status"`
}

GroupEntry Group listing result for one host.

type GroupEntryStatus

type GroupEntryStatus string

GroupEntryStatus The status of the operation for this host.

const (
	GroupEntryStatusFailed  GroupEntryStatus = "failed"
	GroupEntryStatusOk      GroupEntryStatus = "ok"
	GroupEntryStatusSkipped GroupEntryStatus = "skipped"
)

Defines values for GroupEntryStatus.

type GroupInfo

type GroupInfo struct {
	// Gid Numeric group ID.
	Gid *int `json:"gid,omitempty"`

	// Members Group member usernames.
	Members *[]string `json:"members,omitempty"`

	// Name Group name.
	Name *string `json:"name,omitempty"`
}

GroupInfo A group on the target node.

type GroupMutationResponse

type GroupMutationResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID   `json:"job_id,omitempty"`
	Results []GroupMutationResult `json:"results"`
}

GroupMutationResponse defines model for GroupMutationResponse.

type GroupMutationResult

type GroupMutationResult struct {
	// Changed Whether the operation modified system state.
	Changed *bool `json:"changed,omitempty"`

	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Hostname Hostname of the agent that processed this operation.
	Hostname string `json:"hostname"`

	// Name Group name.
	Name *string `json:"name,omitempty"`

	// Status The status of the operation for this host.
	Status GroupMutationResultStatus `json:"status"`
}

GroupMutationResult Result of a group create, update, or delete operation for one host.

type GroupMutationResultStatus

type GroupMutationResultStatus string

GroupMutationResultStatus The status of the operation for this host.

const (
	GroupMutationResultStatusFailed  GroupMutationResultStatus = "failed"
	GroupMutationResultStatusOk      GroupMutationResultStatus = "ok"
	GroupMutationResultStatusSkipped GroupMutationResultStatus = "skipped"
)

Defines values for GroupMutationResultStatus.

type GroupName

type GroupName = string

GroupName defines model for GroupName.

type GroupUpdateRequest

type GroupUpdateRequest struct {
	// Members Group member usernames (replaces existing).
	Members *[]string `json:"members,omitempty"`
}

GroupUpdateRequest defines model for GroupUpdateRequest.

type Hostname

type Hostname = string

Hostname defines model for Hostname.

type PostNodeGroup200JSONResponse

type PostNodeGroup200JSONResponse GroupMutationResponse

func (PostNodeGroup200JSONResponse) VisitPostNodeGroupResponse

func (response PostNodeGroup200JSONResponse) VisitPostNodeGroupResponse(w http.ResponseWriter) error

type PostNodeGroup400JSONResponse

type PostNodeGroup400JSONResponse externalRef0.ErrorResponse

func (PostNodeGroup400JSONResponse) VisitPostNodeGroupResponse

func (response PostNodeGroup400JSONResponse) VisitPostNodeGroupResponse(w http.ResponseWriter) error

type PostNodeGroup401JSONResponse

type PostNodeGroup401JSONResponse externalRef0.ErrorResponse

func (PostNodeGroup401JSONResponse) VisitPostNodeGroupResponse

func (response PostNodeGroup401JSONResponse) VisitPostNodeGroupResponse(w http.ResponseWriter) error

type PostNodeGroup403JSONResponse

type PostNodeGroup403JSONResponse externalRef0.ErrorResponse

func (PostNodeGroup403JSONResponse) VisitPostNodeGroupResponse

func (response PostNodeGroup403JSONResponse) VisitPostNodeGroupResponse(w http.ResponseWriter) error

type PostNodeGroup500JSONResponse

type PostNodeGroup500JSONResponse externalRef0.ErrorResponse

func (PostNodeGroup500JSONResponse) VisitPostNodeGroupResponse

func (response PostNodeGroup500JSONResponse) VisitPostNodeGroupResponse(w http.ResponseWriter) error

type PostNodeGroupJSONRequestBody

type PostNodeGroupJSONRequestBody = GroupCreateRequest

PostNodeGroupJSONRequestBody defines body for PostNodeGroup for application/json ContentType.

type PostNodeGroupRequestObject

type PostNodeGroupRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Body     *PostNodeGroupJSONRequestBody
}

type PostNodeGroupResponseObject

type PostNodeGroupResponseObject interface {
	VisitPostNodeGroupResponse(w http.ResponseWriter) error
}

type PostNodeUser200JSONResponse

type PostNodeUser200JSONResponse UserMutationResponse

func (PostNodeUser200JSONResponse) VisitPostNodeUserResponse

func (response PostNodeUser200JSONResponse) VisitPostNodeUserResponse(w http.ResponseWriter) error

type PostNodeUser400JSONResponse

type PostNodeUser400JSONResponse externalRef0.ErrorResponse

func (PostNodeUser400JSONResponse) VisitPostNodeUserResponse

func (response PostNodeUser400JSONResponse) VisitPostNodeUserResponse(w http.ResponseWriter) error

type PostNodeUser401JSONResponse

type PostNodeUser401JSONResponse externalRef0.ErrorResponse

func (PostNodeUser401JSONResponse) VisitPostNodeUserResponse

func (response PostNodeUser401JSONResponse) VisitPostNodeUserResponse(w http.ResponseWriter) error

type PostNodeUser403JSONResponse

type PostNodeUser403JSONResponse externalRef0.ErrorResponse

func (PostNodeUser403JSONResponse) VisitPostNodeUserResponse

func (response PostNodeUser403JSONResponse) VisitPostNodeUserResponse(w http.ResponseWriter) error

type PostNodeUser500JSONResponse

type PostNodeUser500JSONResponse externalRef0.ErrorResponse

func (PostNodeUser500JSONResponse) VisitPostNodeUserResponse

func (response PostNodeUser500JSONResponse) VisitPostNodeUserResponse(w http.ResponseWriter) error

type PostNodeUserJSONRequestBody

type PostNodeUserJSONRequestBody = UserCreateRequest

PostNodeUserJSONRequestBody defines body for PostNodeUser for application/json ContentType.

type PostNodeUserPassword200JSONResponse

type PostNodeUserPassword200JSONResponse UserMutationResponse

func (PostNodeUserPassword200JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword200JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPassword400JSONResponse

type PostNodeUserPassword400JSONResponse externalRef0.ErrorResponse

func (PostNodeUserPassword400JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword400JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPassword401JSONResponse

type PostNodeUserPassword401JSONResponse externalRef0.ErrorResponse

func (PostNodeUserPassword401JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword401JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPassword403JSONResponse

type PostNodeUserPassword403JSONResponse externalRef0.ErrorResponse

func (PostNodeUserPassword403JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword403JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPassword404JSONResponse

type PostNodeUserPassword404JSONResponse externalRef0.ErrorResponse

func (PostNodeUserPassword404JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword404JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPassword500JSONResponse

type PostNodeUserPassword500JSONResponse externalRef0.ErrorResponse

func (PostNodeUserPassword500JSONResponse) VisitPostNodeUserPasswordResponse

func (response PostNodeUserPassword500JSONResponse) VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error

type PostNodeUserPasswordJSONRequestBody

type PostNodeUserPasswordJSONRequestBody = UserPasswordRequest

PostNodeUserPasswordJSONRequestBody defines body for PostNodeUserPassword for application/json ContentType.

type PostNodeUserPasswordRequestObject

type PostNodeUserPasswordRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
	Body     *PostNodeUserPasswordJSONRequestBody
}

type PostNodeUserPasswordResponseObject

type PostNodeUserPasswordResponseObject interface {
	VisitPostNodeUserPasswordResponse(w http.ResponseWriter) error
}

type PostNodeUserRequestObject

type PostNodeUserRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Body     *PostNodeUserJSONRequestBody
}

type PostNodeUserResponseObject

type PostNodeUserResponseObject interface {
	VisitPostNodeUserResponse(w http.ResponseWriter) error
}

type PostNodeUserSSHKey200JSONResponse

type PostNodeUserSSHKey200JSONResponse SSHKeyMutationResponse

func (PostNodeUserSSHKey200JSONResponse) VisitPostNodeUserSSHKeyResponse

func (response PostNodeUserSSHKey200JSONResponse) VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error

type PostNodeUserSSHKey400JSONResponse

type PostNodeUserSSHKey400JSONResponse externalRef0.ErrorResponse

func (PostNodeUserSSHKey400JSONResponse) VisitPostNodeUserSSHKeyResponse

func (response PostNodeUserSSHKey400JSONResponse) VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error

type PostNodeUserSSHKey401JSONResponse

type PostNodeUserSSHKey401JSONResponse externalRef0.ErrorResponse

func (PostNodeUserSSHKey401JSONResponse) VisitPostNodeUserSSHKeyResponse

func (response PostNodeUserSSHKey401JSONResponse) VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error

type PostNodeUserSSHKey403JSONResponse

type PostNodeUserSSHKey403JSONResponse externalRef0.ErrorResponse

func (PostNodeUserSSHKey403JSONResponse) VisitPostNodeUserSSHKeyResponse

func (response PostNodeUserSSHKey403JSONResponse) VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error

type PostNodeUserSSHKey500JSONResponse

type PostNodeUserSSHKey500JSONResponse externalRef0.ErrorResponse

func (PostNodeUserSSHKey500JSONResponse) VisitPostNodeUserSSHKeyResponse

func (response PostNodeUserSSHKey500JSONResponse) VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error

type PostNodeUserSSHKeyJSONRequestBody

type PostNodeUserSSHKeyJSONRequestBody = SSHKeyAddRequest

PostNodeUserSSHKeyJSONRequestBody defines body for PostNodeUserSSHKey for application/json ContentType.

type PostNodeUserSSHKeyRequestObject

type PostNodeUserSSHKeyRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
	Body     *PostNodeUserSSHKeyJSONRequestBody
}

type PostNodeUserSSHKeyResponseObject

type PostNodeUserSSHKeyResponseObject interface {
	VisitPostNodeUserSSHKeyResponse(w http.ResponseWriter) error
}

type PutNodeGroup200JSONResponse

type PutNodeGroup200JSONResponse GroupMutationResponse

func (PutNodeGroup200JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup200JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroup400JSONResponse

type PutNodeGroup400JSONResponse externalRef0.ErrorResponse

func (PutNodeGroup400JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup400JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroup401JSONResponse

type PutNodeGroup401JSONResponse externalRef0.ErrorResponse

func (PutNodeGroup401JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup401JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroup403JSONResponse

type PutNodeGroup403JSONResponse externalRef0.ErrorResponse

func (PutNodeGroup403JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup403JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroup404JSONResponse

type PutNodeGroup404JSONResponse externalRef0.ErrorResponse

func (PutNodeGroup404JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup404JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroup500JSONResponse

type PutNodeGroup500JSONResponse externalRef0.ErrorResponse

func (PutNodeGroup500JSONResponse) VisitPutNodeGroupResponse

func (response PutNodeGroup500JSONResponse) VisitPutNodeGroupResponse(w http.ResponseWriter) error

type PutNodeGroupJSONRequestBody

type PutNodeGroupJSONRequestBody = GroupUpdateRequest

PutNodeGroupJSONRequestBody defines body for PutNodeGroup for application/json ContentType.

type PutNodeGroupRequestObject

type PutNodeGroupRequestObject struct {
	Hostname Hostname  `json:"hostname"`
	Name     GroupName `json:"name"`
	Body     *PutNodeGroupJSONRequestBody
}

type PutNodeGroupResponseObject

type PutNodeGroupResponseObject interface {
	VisitPutNodeGroupResponse(w http.ResponseWriter) error
}

type PutNodeUser200JSONResponse

type PutNodeUser200JSONResponse UserMutationResponse

func (PutNodeUser200JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser200JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUser400JSONResponse

type PutNodeUser400JSONResponse externalRef0.ErrorResponse

func (PutNodeUser400JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser400JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUser401JSONResponse

type PutNodeUser401JSONResponse externalRef0.ErrorResponse

func (PutNodeUser401JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser401JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUser403JSONResponse

type PutNodeUser403JSONResponse externalRef0.ErrorResponse

func (PutNodeUser403JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser403JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUser404JSONResponse

type PutNodeUser404JSONResponse externalRef0.ErrorResponse

func (PutNodeUser404JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser404JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUser500JSONResponse

type PutNodeUser500JSONResponse externalRef0.ErrorResponse

func (PutNodeUser500JSONResponse) VisitPutNodeUserResponse

func (response PutNodeUser500JSONResponse) VisitPutNodeUserResponse(w http.ResponseWriter) error

type PutNodeUserJSONRequestBody

type PutNodeUserJSONRequestBody = UserUpdateRequest

PutNodeUserJSONRequestBody defines body for PutNodeUser for application/json ContentType.

type PutNodeUserRequestObject

type PutNodeUserRequestObject struct {
	Hostname Hostname `json:"hostname"`
	Name     UserName `json:"name"`
	Body     *PutNodeUserJSONRequestBody
}

type PutNodeUserResponseObject

type PutNodeUserResponseObject interface {
	VisitPutNodeUserResponse(w http.ResponseWriter) error
}

type SSHKeyAddRequest

type SSHKeyAddRequest struct {
	// Key Full SSH public key line (e.g., "ssh-ed25519 AAAA... user@host").
	Key string `json:"key" validate:"required,min=1"`
}

SSHKeyAddRequest defines model for SSHKeyAddRequest.

type SSHKeyCollectionResponse

type SSHKeyCollectionResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID `json:"job_id,omitempty"`
	Results []SSHKeyEntry       `json:"results"`
}

SSHKeyCollectionResponse defines model for SSHKeyCollectionResponse.

type SSHKeyEntry

type SSHKeyEntry struct {
	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Hostname The hostname of the agent.
	Hostname string `json:"hostname"`

	// Keys SSH authorized keys on this agent.
	Keys *[]SSHKeyInfo `json:"keys,omitempty"`

	// Status The status of the operation for this host.
	Status SSHKeyEntryStatus `json:"status"`
}

SSHKeyEntry SSH key list result for a single agent.

type SSHKeyEntryStatus

type SSHKeyEntryStatus string

SSHKeyEntryStatus The status of the operation for this host.

const (
	SSHKeyEntryStatusFailed  SSHKeyEntryStatus = "failed"
	SSHKeyEntryStatusOk      SSHKeyEntryStatus = "ok"
	SSHKeyEntryStatusSkipped SSHKeyEntryStatus = "skipped"
)

Defines values for SSHKeyEntryStatus.

type SSHKeyFingerprint

type SSHKeyFingerprint = string

SSHKeyFingerprint defines model for SSHKeyFingerprint.

type SSHKeyInfo

type SSHKeyInfo struct {
	// Comment Key comment (typically user@host).
	Comment *string `json:"comment,omitempty"`

	// Fingerprint SHA256 fingerprint of the key.
	Fingerprint *string `json:"fingerprint,omitempty"`

	// Type Key type (e.g., ssh-rsa, ssh-ed25519).
	Type *string `json:"type,omitempty"`
}

SSHKeyInfo An SSH authorized key entry.

type SSHKeyMutationEntry

type SSHKeyMutationEntry struct {
	// Changed Whether the operation modified system state.
	Changed *bool `json:"changed,omitempty"`

	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Hostname The hostname of the agent.
	Hostname string `json:"hostname"`

	// Status The status of the operation for this host.
	Status SSHKeyMutationEntryStatus `json:"status"`
}

SSHKeyMutationEntry SSH key mutation result for a single agent.

type SSHKeyMutationEntryStatus

type SSHKeyMutationEntryStatus string

SSHKeyMutationEntryStatus The status of the operation for this host.

const (
	SSHKeyMutationEntryStatusFailed  SSHKeyMutationEntryStatus = "failed"
	SSHKeyMutationEntryStatusOk      SSHKeyMutationEntryStatus = "ok"
	SSHKeyMutationEntryStatusSkipped SSHKeyMutationEntryStatus = "skipped"
)

Defines values for SSHKeyMutationEntryStatus.

type SSHKeyMutationResponse

type SSHKeyMutationResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID   `json:"job_id,omitempty"`
	Results []SSHKeyMutationEntry `json:"results"`
}

SSHKeyMutationResponse defines model for SSHKeyMutationResponse.

type ServerInterface

type ServerInterface interface {
	// List all groups
	// (GET /api/node/{hostname}/group)
	GetNodeGroup(ctx echo.Context, hostname Hostname) error
	// Create a group
	// (POST /api/node/{hostname}/group)
	PostNodeGroup(ctx echo.Context, hostname Hostname) error
	// Delete a group
	// (DELETE /api/node/{hostname}/group/{name})
	DeleteNodeGroup(ctx echo.Context, hostname Hostname, name GroupName) error
	// Get a group
	// (GET /api/node/{hostname}/group/{name})
	GetNodeGroupByName(ctx echo.Context, hostname Hostname, name GroupName) error
	// Update a group
	// (PUT /api/node/{hostname}/group/{name})
	PutNodeGroup(ctx echo.Context, hostname Hostname, name GroupName) error
	// List all users
	// (GET /api/node/{hostname}/user)
	GetNodeUser(ctx echo.Context, hostname Hostname) error
	// Create a user
	// (POST /api/node/{hostname}/user)
	PostNodeUser(ctx echo.Context, hostname Hostname) error
	// Delete a user
	// (DELETE /api/node/{hostname}/user/{name})
	DeleteNodeUser(ctx echo.Context, hostname Hostname, name UserName) error
	// Get a user
	// (GET /api/node/{hostname}/user/{name})
	GetNodeUserByName(ctx echo.Context, hostname Hostname, name UserName) error
	// Update a user
	// (PUT /api/node/{hostname}/user/{name})
	PutNodeUser(ctx echo.Context, hostname Hostname, name UserName) error
	// Change user password
	// (POST /api/node/{hostname}/user/{name}/password)
	PostNodeUserPassword(ctx echo.Context, hostname Hostname, name UserName) error
	// List SSH authorized keys
	// (GET /api/node/{hostname}/user/{name}/ssh-key)
	GetNodeUserSSHKey(ctx echo.Context, hostname Hostname, name UserName) error
	// Add SSH authorized key
	// (POST /api/node/{hostname}/user/{name}/ssh-key)
	PostNodeUserSSHKey(ctx echo.Context, hostname Hostname, name UserName) error
	// Remove SSH authorized key
	// (DELETE /api/node/{hostname}/user/{name}/ssh-key/{fingerprint})
	DeleteNodeUserSSHKey(ctx echo.Context, hostname Hostname, name UserName, fingerprint SSHKeyFingerprint) error
}

ServerInterface represents all server handlers.

func NewStrictHandler

func NewStrictHandler(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc) ServerInterface

type ServerInterfaceWrapper

type ServerInterfaceWrapper struct {
	Handler ServerInterface
}

ServerInterfaceWrapper converts echo contexts to parameters.

func (*ServerInterfaceWrapper) DeleteNodeGroup

func (w *ServerInterfaceWrapper) DeleteNodeGroup(ctx echo.Context) error

DeleteNodeGroup converts echo context to params.

func (*ServerInterfaceWrapper) DeleteNodeUser

func (w *ServerInterfaceWrapper) DeleteNodeUser(ctx echo.Context) error

DeleteNodeUser converts echo context to params.

func (*ServerInterfaceWrapper) DeleteNodeUserSSHKey

func (w *ServerInterfaceWrapper) DeleteNodeUserSSHKey(ctx echo.Context) error

DeleteNodeUserSSHKey converts echo context to params.

func (*ServerInterfaceWrapper) GetNodeGroup

func (w *ServerInterfaceWrapper) GetNodeGroup(ctx echo.Context) error

GetNodeGroup converts echo context to params.

func (*ServerInterfaceWrapper) GetNodeGroupByName

func (w *ServerInterfaceWrapper) GetNodeGroupByName(ctx echo.Context) error

GetNodeGroupByName converts echo context to params.

func (*ServerInterfaceWrapper) GetNodeUser

func (w *ServerInterfaceWrapper) GetNodeUser(ctx echo.Context) error

GetNodeUser converts echo context to params.

func (*ServerInterfaceWrapper) GetNodeUserByName

func (w *ServerInterfaceWrapper) GetNodeUserByName(ctx echo.Context) error

GetNodeUserByName converts echo context to params.

func (*ServerInterfaceWrapper) GetNodeUserSSHKey

func (w *ServerInterfaceWrapper) GetNodeUserSSHKey(ctx echo.Context) error

GetNodeUserSSHKey converts echo context to params.

func (*ServerInterfaceWrapper) PostNodeGroup

func (w *ServerInterfaceWrapper) PostNodeGroup(ctx echo.Context) error

PostNodeGroup converts echo context to params.

func (*ServerInterfaceWrapper) PostNodeUser

func (w *ServerInterfaceWrapper) PostNodeUser(ctx echo.Context) error

PostNodeUser converts echo context to params.

func (*ServerInterfaceWrapper) PostNodeUserPassword

func (w *ServerInterfaceWrapper) PostNodeUserPassword(ctx echo.Context) error

PostNodeUserPassword converts echo context to params.

func (*ServerInterfaceWrapper) PostNodeUserSSHKey

func (w *ServerInterfaceWrapper) PostNodeUserSSHKey(ctx echo.Context) error

PostNodeUserSSHKey converts echo context to params.

func (*ServerInterfaceWrapper) PutNodeGroup

func (w *ServerInterfaceWrapper) PutNodeGroup(ctx echo.Context) error

PutNodeGroup converts echo context to params.

func (*ServerInterfaceWrapper) PutNodeUser

func (w *ServerInterfaceWrapper) PutNodeUser(ctx echo.Context) error

PutNodeUser converts echo context to params.

type StrictHandlerFunc

type StrictHandlerFunc = strictecho.StrictEchoHandlerFunc

type StrictMiddlewareFunc

type StrictMiddlewareFunc = strictecho.StrictEchoMiddlewareFunc

type StrictServerInterface

type StrictServerInterface interface {
	// List all groups
	// (GET /api/node/{hostname}/group)
	GetNodeGroup(ctx context.Context, request GetNodeGroupRequestObject) (GetNodeGroupResponseObject, error)
	// Create a group
	// (POST /api/node/{hostname}/group)
	PostNodeGroup(ctx context.Context, request PostNodeGroupRequestObject) (PostNodeGroupResponseObject, error)
	// Delete a group
	// (DELETE /api/node/{hostname}/group/{name})
	DeleteNodeGroup(ctx context.Context, request DeleteNodeGroupRequestObject) (DeleteNodeGroupResponseObject, error)
	// Get a group
	// (GET /api/node/{hostname}/group/{name})
	GetNodeGroupByName(ctx context.Context, request GetNodeGroupByNameRequestObject) (GetNodeGroupByNameResponseObject, error)
	// Update a group
	// (PUT /api/node/{hostname}/group/{name})
	PutNodeGroup(ctx context.Context, request PutNodeGroupRequestObject) (PutNodeGroupResponseObject, error)
	// List all users
	// (GET /api/node/{hostname}/user)
	GetNodeUser(ctx context.Context, request GetNodeUserRequestObject) (GetNodeUserResponseObject, error)
	// Create a user
	// (POST /api/node/{hostname}/user)
	PostNodeUser(ctx context.Context, request PostNodeUserRequestObject) (PostNodeUserResponseObject, error)
	// Delete a user
	// (DELETE /api/node/{hostname}/user/{name})
	DeleteNodeUser(ctx context.Context, request DeleteNodeUserRequestObject) (DeleteNodeUserResponseObject, error)
	// Get a user
	// (GET /api/node/{hostname}/user/{name})
	GetNodeUserByName(ctx context.Context, request GetNodeUserByNameRequestObject) (GetNodeUserByNameResponseObject, error)
	// Update a user
	// (PUT /api/node/{hostname}/user/{name})
	PutNodeUser(ctx context.Context, request PutNodeUserRequestObject) (PutNodeUserResponseObject, error)
	// Change user password
	// (POST /api/node/{hostname}/user/{name}/password)
	PostNodeUserPassword(ctx context.Context, request PostNodeUserPasswordRequestObject) (PostNodeUserPasswordResponseObject, error)
	// List SSH authorized keys
	// (GET /api/node/{hostname}/user/{name}/ssh-key)
	GetNodeUserSSHKey(ctx context.Context, request GetNodeUserSSHKeyRequestObject) (GetNodeUserSSHKeyResponseObject, error)
	// Add SSH authorized key
	// (POST /api/node/{hostname}/user/{name}/ssh-key)
	PostNodeUserSSHKey(ctx context.Context, request PostNodeUserSSHKeyRequestObject) (PostNodeUserSSHKeyResponseObject, error)
	// Remove SSH authorized key
	// (DELETE /api/node/{hostname}/user/{name}/ssh-key/{fingerprint})
	DeleteNodeUserSSHKey(ctx context.Context, request DeleteNodeUserSSHKeyRequestObject) (DeleteNodeUserSSHKeyResponseObject, error)
}

StrictServerInterface represents all server handlers.

type UserCollectionResponse

type UserCollectionResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID `json:"job_id,omitempty"`
	Results []UserEntry         `json:"results"`
}

UserCollectionResponse defines model for UserCollectionResponse.

type UserCreateRequest

type UserCreateRequest struct {
	// Gid Primary group ID. If omitted, a group matching the username is created.
	Gid *int `json:"gid,omitempty" validate:"omitempty,min=0"`

	// Groups Supplementary group names.
	Groups *[]string `json:"groups,omitempty"`

	// Home Home directory path.
	Home *string `json:"home,omitempty" validate:"omitempty,min=1"`

	// Name Username for the new account.
	Name string `json:"name" validate:"required,min=1,max=32"`

	// Password Initial password (plaintext, hashed by the agent).
	Password *string `json:"password,omitempty" validate:"omitempty,min=1"`

	// Shell Login shell path.
	Shell *string `json:"shell,omitempty" validate:"omitempty,min=1"`

	// System Create a system account.
	System *bool `json:"system,omitempty" validate:"omitempty"`

	// Uid Numeric user ID. If omitted, the system assigns one.
	Uid *int `json:"uid,omitempty" validate:"omitempty,min=0"`
}

UserCreateRequest defines model for UserCreateRequest.

type UserEntry

type UserEntry struct {
	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Hostname Hostname of the agent that reported this entry.
	Hostname string `json:"hostname"`

	// Status The status of the operation for this host.
	Status UserEntryStatus `json:"status"`

	// Users User accounts on this host.
	Users *[]UserInfo `json:"users,omitempty"`
}

UserEntry User listing result for one host.

type UserEntryStatus

type UserEntryStatus string

UserEntryStatus The status of the operation for this host.

const (
	UserEntryStatusFailed  UserEntryStatus = "failed"
	UserEntryStatusOk      UserEntryStatus = "ok"
	UserEntryStatusSkipped UserEntryStatus = "skipped"
)

Defines values for UserEntryStatus.

type UserInfo

type UserInfo struct {
	// Gid Primary group ID.
	Gid *int `json:"gid,omitempty"`

	// Groups Supplementary group names.
	Groups *[]string `json:"groups,omitempty"`

	// Home Home directory path.
	Home *string `json:"home,omitempty"`

	// Locked Whether the account is locked.
	Locked *bool `json:"locked,omitempty"`

	// Name Username.
	Name *string `json:"name,omitempty"`

	// Shell Login shell path.
	Shell *string `json:"shell,omitempty"`

	// Uid Numeric user ID.
	Uid *int `json:"uid,omitempty"`
}

UserInfo A user account on the target node.

type UserMutationResponse

type UserMutationResponse struct {
	// JobId The job ID used to process this request.
	JobId   *openapi_types.UUID  `json:"job_id,omitempty"`
	Results []UserMutationResult `json:"results"`
}

UserMutationResponse defines model for UserMutationResponse.

type UserMutationResult

type UserMutationResult struct {
	// Changed Whether the operation modified system state.
	Changed *bool `json:"changed,omitempty"`

	// Error Error message if the agent failed.
	Error *string `json:"error,omitempty"`

	// Hostname Hostname of the agent that processed this operation.
	Hostname string `json:"hostname"`

	// Name Username.
	Name *string `json:"name,omitempty"`

	// Status The status of the operation for this host.
	Status UserMutationResultStatus `json:"status"`
}

UserMutationResult Result of a user create, update, delete, or password operation for one host.

type UserMutationResultStatus

type UserMutationResultStatus string

UserMutationResultStatus The status of the operation for this host.

const (
	UserMutationResultStatusFailed  UserMutationResultStatus = "failed"
	UserMutationResultStatusOk      UserMutationResultStatus = "ok"
	UserMutationResultStatusSkipped UserMutationResultStatus = "skipped"
)

Defines values for UserMutationResultStatus.

type UserName

type UserName = string

UserName defines model for UserName.

type UserPasswordRequest

type UserPasswordRequest struct {
	// Password New password (plaintext, hashed by the agent).
	Password string `json:"password" validate:"required,min=1"`
}

UserPasswordRequest defines model for UserPasswordRequest.

type UserUpdateRequest

type UserUpdateRequest struct {
	// Groups Supplementary group names (replaces existing).
	Groups *[]string `json:"groups,omitempty"`

	// Home New home directory path.
	Home *string `json:"home,omitempty" validate:"omitempty,min=1"`

	// Lock Lock or unlock the account.
	Lock *bool `json:"lock,omitempty" validate:"omitempty"`

	// Shell New login shell path.
	Shell *string `json:"shell,omitempty" validate:"omitempty,min=1"`
}

UserUpdateRequest defines model for UserUpdateRequest.

Jump to